YandexoauthPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- YandexoauthPlatform
- Implementers
Constructors
- YandexoauthPlatform()
- Constructs a YandexoauthPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCertificateFingerprint(
{FingerprintType type = FingerprintType.sha1}) → Future< FingerprintModel> -
getPlatformVersion(
) → Future< String?> -
logoutYandex(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signInWithYandex(
) → Future< YandexAuthResult> -
startYandexSdk(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ YandexoauthPlatform
-
The default instance of YandexoauthPlatform to use.
getter/setter pair